@@ -478,6 +478,9 @@ arv_gc_property_node_type_get_type (void)
 			{ ARV_GC_PROPERTY_NODE_TYPE_P_IS_IMPLEMENTED,
 			  "ARV_GC_PROPERTY_NODE_TYPE_P_IS_IMPLEMENTED",
 			  "p-is-implemented" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_IS_LOCKED,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_IS_LOCKED",
+			  "p-is-locked" },
 			{ ARV_GC_PROPERTY_NODE_TYPE_P_IS_AVAILABLE,
 			  "ARV_GC_PROPERTY_NODE_TYPE_P_IS_AVAILABLE",
 			  "p-is-available" },
@@ -780,6 +783,9 @@ arv_gvcp_command_get_type (void)
 			{ ARV_GVCP_COMMAND_WRITE_MEMORY_ACK,
 			  "ARV_GVCP_COMMAND_WRITE_MEMORY_ACK",
 			  "write-memory-ack" },
+			{ ARV_GVCP_COMMAND_PENDING_ACK,
+			  "ARV_GVCP_COMMAND_PENDING_ACK",
+			  "pending-ack" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
