@@ -30,6 +30,7 @@
 #include <arvdebug.h>
 
 #define ARV_FAKE_DEVICE_ID "Fake_1"
+#define ARV_FAKE_PHYSICAL_ID "Fake_1"
 
 static GObjectClass *parent_class = NULL;
 
@@ -40,11 +41,16 @@ struct _ArvFakeInterfacePrivate {
 static void
 arv_fake_interface_update_device_list (ArvInterface *interface, GArray *device_ids)
 {
-	char *device_id;
+	ArvInterfaceDeviceIds *ids;
+
+	ids = g_new0 (ArvInterfaceDeviceIds, 1);
 
 	g_array_set_size (device_ids, 0);
-	device_id = g_strdup (ARV_FAKE_DEVICE_ID);
-	g_array_append_val (device_ids, device_id);
+
+	ids->device = g_strdup (ARV_FAKE_DEVICE_ID);
+	ids->physical = g_strdup (ARV_FAKE_PHYSICAL_ID);
+
+	g_array_append_val (device_ids, ids);
 }
 
 static ArvDevice *
@@ -52,6 +58,8 @@ arv_fake_interface_open_device (ArvInterface *interface, const char *device_id)
 {
 	if (g_strcmp0 (device_id, ARV_FAKE_DEVICE_ID) == 0)
 		return arv_fake_device_new ("1");
+	if (g_strcmp0 (device_id, ARV_FAKE_PHYSICAL_ID) == 0)
+		return arv_fake_device_new ("1");
 
 	return NULL;
 }
