@@ -59,6 +59,8 @@ const char *		arv_gc_feature_node_get_name			(ArvGcFeatureNode *gc_feature_node)
 const char *		arv_gc_feature_node_get_tooltip			(ArvGcFeatureNode *gc_feature_node);
 const char *		arv_gc_feature_node_get_description		(ArvGcFeatureNode *gc_feature_node);
 gboolean		arv_gc_feature_node_is_available		(ArvGcFeatureNode *gc_feature_node);
+gboolean		arv_gc_feature_node_is_implemented		(ArvGcFeatureNode *gc_feature_node);
+gboolean		arv_gc_feature_node_is_locked			(ArvGcFeatureNode *gc_feature_node);
 GType 			arv_gc_feature_node_get_value_type 		(ArvGcFeatureNode *gc_feature_node);
 void			arv_gc_feature_node_set_value_from_string	(ArvGcFeatureNode *gc_feature_node, const char *string);
 const char *		arv_gc_feature_node_get_value_as_string		(ArvGcFeatureNode *gc_feature_node);
