@@ -30,6 +30,7 @@
 #include <arvdebug.h>
 #include <arvgvstream.h>
 #include <arvgvcp.h>
+#include <arvgvsp.h>
 #include <arvzip.h>
 #include <string.h>
 #include <stdlib.h>
@@ -453,26 +454,15 @@ arv_gv_device_get_timestamp_tick_frequency (ArvGvDevice *gv_device)
 guint
 arv_gv_device_get_packet_size (ArvGvDevice *gv_device)
 {
-	guint32 packet_size;
-
-	g_return_val_if_fail (ARV_IS_GV_DEVICE (gv_device), 0);
-
-	arv_device_read_register (ARV_DEVICE (gv_device),
-				  ARV_GVBS_STREAM_CHANNEL_0_PACKET_SIZE_OFFSET,
-				  &packet_size);
-
-	return packet_size;
+	return arv_device_get_integer_feature_value (ARV_DEVICE (gv_device), "GevSCPSPacketSize");
 }
 
 void
 arv_gv_device_set_packet_size (ArvGvDevice *gv_device, guint packet_size)
 {
-	g_return_if_fail (ARV_IS_GV_DEVICE (gv_device));
 	g_return_if_fail (packet_size > 0);
 
-	arv_device_write_register (ARV_DEVICE (gv_device),
-				  ARV_GVBS_STREAM_CHANNEL_0_PACKET_SIZE_OFFSET,
-				  packet_size);
+	arv_device_set_integer_feature_value (ARV_DEVICE (gv_device), "GevSCPSPacketSize", packet_size);
 }
 
 static char *
@@ -588,8 +578,34 @@ arv_gv_device_load_genicam (ArvGvDevice *gv_device)
 	size_t size;
 
 	genicam = arv_gv_device_get_genicam_xml (ARV_DEVICE (gv_device), &size);
-	if (genicam != NULL)
+	if (genicam != NULL) {
 		gv_device->priv->genicam = arv_gc_new (ARV_DEVICE (gv_device), genicam, size);
+
+		arv_gc_set_default_node_data (gv_device->priv->genicam, "GevSCPSPacketSize",
+					      "<Integer Name=\"GevSCPSPacketSize\">"
+					      "<Visibility>Expert</Visibility>"
+					      "<pIsLocked>TLParamsLocked</pIsLocked>"
+					      "<pValue>GevSCPSPacketSizeReg</pValue>"
+					      "</Integer>");
+		arv_gc_set_default_node_data (gv_device->priv->genicam, "GevSCPSPacketSizeReg",
+					      "<MaskedIntReg Name=\"GevSCPSPacketSizeReg\">"
+					      "<Address>0xd04</Address>"
+					      "<Length>4</Length>"
+					      "<AccessMode>RW</AccessMode>"
+					      "<pPort>Device</pPort>"
+					      "<LSB>31</LSB>"
+					      "<MSB>16</MSB>"
+					      "<Sign>Unsigned</Sign>"
+					      "<Endianess>BigEndian</Endianess>"
+					      "</MaskedIntReg>");
+		arv_gc_set_default_node_data (gv_device->priv->genicam, "TLParamsLocked",
+					      "<Integer Name=\"TLParamsLocked\">"
+					      "<Visibility>Invisible</Visibility>"
+					      "<Value>0</Value>"
+					      "<Min>0</Min>"
+					      "<Max>1</Max>"
+					      "</Integer>");
+	}
 }
 
 /* ArvDevice implemenation */
@@ -622,9 +638,16 @@ arv_gv_device_create_stream (ArvDevice *device, ArvStreamCallback callback, void
 	device_address = g_inet_socket_address_get_address (G_INET_SOCKET_ADDRESS (io_data->device_address));
 	address_bytes = g_inet_address_to_bytes (interface_address);
 
-	arv_gv_device_set_packet_size (gv_device, ARV_GV_DEVICE_GVSP_PACKET_SIZE_DEFAULT);
+	/* On some cameras, the default packet size after reset is incorrect.
+	 * So, if the value is obviously incorrect, set it to a default size. */
 	packet_size = arv_gv_device_get_packet_size (gv_device);
+	if (packet_size <= ARV_GVSP_PACKET_PROTOCOL_OVERHEAD) {
+		arv_gv_device_set_packet_size (gv_device, ARV_GV_DEVICE_GVSP_PACKET_SIZE_DEFAULT);
+		arv_debug_device ("[GvDevice::create_stream] Packet size set to default value (%d)",
+				  ARV_GV_DEVICE_GVSP_PACKET_SIZE_DEFAULT);
+	}
 
+	packet_size = arv_gv_device_get_packet_size (gv_device);
 	arv_debug_device ("[GvDevice::create_stream] Packet size = %d byte(s)", packet_size);
 
 	stream = arv_gv_stream_new (device_address, 0, callback, user_data,
@@ -809,6 +832,38 @@ arv_gv_device_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
+/**
+ * arv_gv_device_get_interface_address:
+ * @device: a #ArvGvDevice
+ *
+ * Returns: (transfer none): the device host interface IP address.
+ * 
+ * since: 0.1.13
+ */
+
+GSocketAddress *arv_gv_device_get_interface_address(ArvGvDevice *device)
+{
+	ArvGvDeviceIOData *io_data = device->priv->io_data;
+
+	return io_data->interface_address;
+}
+
+/**
+ * arv_gv_device_get_device_address:
+ * @device: a #ArvGvDevice
+ *
+ * Returns: (transfer none): the device IP address.
+ *
+ * since: 0.1.13
+ */
+
+GSocketAddress *arv_gv_device_get_device_address(ArvGvDevice *device)
+{
+	ArvGvDeviceIOData *io_data = device->priv->io_data;
+
+	return io_data->device_address;
+}
+
 static void
 arv_gv_device_class_init (ArvGvDeviceClass *gv_device_class)
 {
