@@ -22,6 +22,15 @@ integer_test (void)
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node));
 	g_assert_cmpint (v_int64, ==, 1);
 
+	v_int64 = arv_gc_integer_get_min (ARV_GC_INTEGER (node));
+	g_assert_cmpint (v_int64, ==, -10);
+
+	v_int64 = arv_gc_integer_get_max (ARV_GC_INTEGER (node));
+	g_assert_cmpint (v_int64, ==, 10);
+
+	v_int64 = arv_gc_integer_get_inc (ARV_GC_INTEGER (node));
+	g_assert_cmpint (v_int64, ==, 2);
+
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node));
 	g_assert_cmpstr (v_string, ==, "1");
 
@@ -35,6 +44,15 @@ integer_test (void)
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node));
 	g_assert_cmpint (v_int64, ==, 2);
 
+	v_int64 = arv_gc_integer_get_min (ARV_GC_INTEGER (node));
+	g_assert_cmpint (v_int64, ==, -20);
+
+	v_int64 = arv_gc_integer_get_max (ARV_GC_INTEGER (node));
+	g_assert_cmpint (v_int64, ==, 20);
+
+	v_int64 = arv_gc_integer_get_inc (ARV_GC_INTEGER (node));
+	g_assert_cmpint (v_int64, ==, 3);
+
 	g_object_unref (device);
 }
 
@@ -108,6 +126,15 @@ float_test (void)
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node));
 	g_assert_cmpfloat (v_double, ==, 0.1);
 
+	v_double = arv_gc_float_get_min (ARV_GC_FLOAT (node));
+	g_assert_cmpfloat (v_double, ==, -10.0);
+
+	v_double = arv_gc_float_get_max (ARV_GC_FLOAT (node));
+	g_assert_cmpfloat (v_double, ==, 10.0);
+
+	v_double = arv_gc_float_get_inc (ARV_GC_FLOAT (node));
+	g_assert_cmpfloat (v_double, ==, 2.0);
+
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node));
 	g_assert_cmpstr (v_string, ==, "0.1");
 
@@ -121,6 +148,15 @@ float_test (void)
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node));
 	g_assert_cmpfloat (v_double, ==, 0.2);
 
+	v_double = arv_gc_float_get_min (ARV_GC_FLOAT (node));
+	g_assert_cmpfloat (v_double, ==, -20.0);
+
+	v_double = arv_gc_float_get_max (ARV_GC_FLOAT (node));
+	g_assert_cmpfloat (v_double, ==, 20.0);
+
+	v_double = arv_gc_float_get_inc (ARV_GC_FLOAT (node));
+	g_assert_cmpfloat (v_double, ==, 3.0);
+
 	g_object_unref (device);
 }
 
@@ -155,6 +191,58 @@ enumeration_test (void)
 	g_object_unref (device);
 }
 
+static void
+swiss_knife_test (void)
+{
+	ArvDevice *device;
+	ArvGc *genicam;
+	ArvGcNode *node;
+	gint64 value;
+
+	device = arv_fake_device_new ("TEST0");
+	g_assert (ARV_IS_FAKE_DEVICE (device));
+
+	genicam = arv_device_get_genicam (device);
+	g_assert (ARV_IS_GC (genicam));
+
+	node = arv_gc_get_node (genicam, "IntSwissKnifeTest");
+	g_assert (ARV_IS_GC_SWISS_KNIFE (node));
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node));
+	g_assert_cmpint (value, ==, 0x1234);
+
+	g_object_unref (device);
+}
+
+static void
+register_test (void)
+{
+	ArvDevice *device;
+	ArvGc *genicam;
+	ArvGcNode *node;
+	gint64 value;
+
+	device = arv_fake_device_new ("TEST0");
+	g_assert (ARV_IS_FAKE_DEVICE (device));
+
+	genicam = arv_device_get_genicam (device);
+	g_assert (ARV_IS_GC (genicam));
+
+	node = arv_gc_get_node (genicam, "IntRegisterA");
+	g_assert (ARV_IS_GC_REGISTER (node));
+
+	value = arv_gc_register_get_address (ARV_GC_REGISTER (node));
+	g_assert_cmpint (value, ==, 0x1050);
+
+	node = arv_gc_get_node (genicam, "IntRegisterB");
+	g_assert (ARV_IS_GC_REGISTER (node));
+
+	value = arv_gc_register_get_address (ARV_GC_REGISTER (node));
+	g_assert_cmpint (value, ==, 0x20ff);
+
+	g_object_unref (device);
+}
+
 GRegex *arv_gv_device_get_url_regex (void);
 
 static void
@@ -176,6 +264,26 @@ url_test (void)
 	g_strfreev (tokens);
 }
 
+static void
+mandatory_test (void)
+{
+	ArvDevice *device;
+	ArvGc *genicam;
+	ArvGcNode *node;
+	gint64 value;
+
+	device = arv_fake_device_new ("TEST0");
+	g_assert (ARV_IS_FAKE_DEVICE (device));
+
+	genicam = arv_device_get_genicam (device);
+	g_assert (ARV_IS_GC (genicam));
+
+	node = arv_gc_get_node (genicam, "TLParamsLocked");
+	g_assert (ARV_IS_GC_INTEGER (node));
+
+	g_object_unref (device);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -192,7 +300,10 @@ main (int argc, char *argv[])
 	g_test_add_func ("/genicam/boolean", boolean_test);
 	g_test_add_func ("/genicam/float", float_test);
 	g_test_add_func ("/genicam/enumeration", enumeration_test);
+	g_test_add_func ("/genicam/swissknife", swiss_knife_test);
+	g_test_add_func ("/genicam/register", register_test);
 	g_test_add_func ("/genicam/url", url_test);
+	g_test_add_func ("/genicam/mandatory", mandatory_test);
 
 	result = g_test_run();
 
